package com.zanxiang.manage.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.zanxiang.common.domain.ResultVo;
import com.zanxiang.manage.domain.params.*;
import com.zanxiang.manage.domain.vo.IpBanVO;
import com.zanxiang.manage.domain.vo.UserBanVO;
import com.zanxiang.manage.service.IpBanService;
import com.zanxiang.manage.service.UserBanService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author : lingfeng
 * @time : 2022-06-28
 * @description : 封禁管理接口
 */
@Api(tags = {"封禁管理接口"})
@RestController
@RequestMapping("/ban")
@Slf4j
public class BanController {

    @Autowired
    private IpBanService ipBanService;

    @Autowired
    private UserBanService userBanService;

    @ApiOperation(value = "查询ip封禁列表")
    @PostMapping(value = "/ip/list")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = IpBanVO.class)})
    public ResultVo<IPage<IpBanVO>> list(@Validated @RequestBody IpBanListParam param) {
        return new ResultVo<>(ipBanService.list(param));
    }

    @ApiOperation(value = "添加封禁ip")
    @PostMapping(value = "/ip/add")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = Boolean.class)})
    public ResultVo<Boolean> addIp(@Validated @RequestBody IpBanAddParam param) {
        return new ResultVo<>(ipBanService.addIp(param));
    }

    @ApiOperation(value = "ip封禁或者解封")
    @PostMapping(value = "/ip/update")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = Boolean.class)})
    public ResultVo<Boolean> ipBanOrRemove(@Validated @RequestBody IpBanUpdateParam param) {
        return new ResultVo<>(ipBanService.ipBanOrRemove(param));
    }

    @ApiOperation(value = "查询玩家封禁列表")
    @PostMapping(value = "/user/list")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = UserBanVO.class)})
    public ResultVo<IPage<UserBanVO>> list(@Validated @RequestBody UserBanListParam param) {
        return new ResultVo<>(userBanService.list(param));
    }

    @ApiOperation(value = "玩家封禁添加或者更新")
    @PostMapping(value = "/user/add/or/update")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = Boolean.class)})
    public ResultVo<Boolean> addOrUpdate(@Validated @RequestBody UserBanUpdateParam param) {
        return new ResultVo<>(userBanService.addOrUpdate(param));
    }
}
